pub trait EscrowFields: LedgerObjectCommonFields {
Show 17 methods
// Provided methods
fn account(&self) -> Result<AccountID> { ... }
fn sequence(&self) -> Result<Option<u32>> { ... }
fn destination(&self) -> Result<AccountID> { ... }
fn amount(&self) -> Result<Amount> { ... }
fn condition(&self) -> Result<Option<ConditionBlob>> { ... }
fn cancel_after(&self) -> Result<Option<u32>> { ... }
fn finish_after(&self) -> Result<Option<u32>> { ... }
fn bytecode(&self) -> Result<Option<WasmBlob>> { ... }
fn data(&self) -> Result<Option<ContractData>> { ... }
fn source_tag(&self) -> Result<Option<u32>> { ... }
fn destination_tag(&self) -> Result<Option<u32>> { ... }
fn owner_node(&self) -> Result<u64> { ... }
fn previous_txn_id(&self) -> Result<Hash256> { ... }
fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
fn destination_node(&self) -> Result<Option<u64>> { ... }
fn transfer_rate(&self) -> Result<Option<u32>> { ... }
fn issuer_node(&self) -> Result<Option<u64>> { ... }
}Expand description
Trait providing access to fields specific to Escrow objects in any ledger.
Provided Methods
Sourcefn account(&self) -> Result<AccountID>
fn account(&self) -> Result<AccountID>
The address of the owner (sender) of this escrow. This is the account that provided the funds, and gets it back if the escrow is canceled.
Sourcefn destination(&self) -> Result<AccountID>
fn destination(&self) -> Result<AccountID>
The destination address where the XRP is paid if the escrow is successful.
Sourcefn amount(&self) -> Result<Amount>
fn amount(&self) -> Result<Amount>
The amount to be delivered by the payment in escrow. The amount can be XRP, or with the TokenEscrow amendment, a fungible token.
Sourcefn condition(&self) -> Result<Option<ConditionBlob>>
fn condition(&self) -> Result<Option<ConditionBlob>>
A PREIMAGE-SHA-256 crypto-condition, as hexadecimal. If present, the EscrowFinish transaction must contain a fulfillment that satisfies this condition.
Sourcefn cancel_after(&self) -> Result<Option<u32>>
fn cancel_after(&self) -> Result<Option<u32>>
The escrow can be canceled if and only if this field is present and the time it specifies has passed. Specifically, this is specified as seconds since the Ripple Epoch and it “has passed” if it’s earlier than the close time of the previous validated ledger.
Sourcefn finish_after(&self) -> Result<Option<u32>>
fn finish_after(&self) -> Result<Option<u32>>
The time, in seconds since the Ripple Epoch, after which this escrow can be finished. Any EscrowFinish transaction before this time fails. (Specifically, this is compared with the close time of the previous validated ledger.)
Sourcefn data(&self) -> Result<Option<ContractData>>
fn data(&self) -> Result<Option<ContractData>>
The Data field (Optional).
Sourcefn source_tag(&self) -> Result<Option<u32>>
fn source_tag(&self) -> Result<Option<u32>>
An arbitrary tag to further specify the source for this escrow, such as a hosted recipient at the owner’s address.
Sourcefn destination_tag(&self) -> Result<Option<u32>>
fn destination_tag(&self) -> Result<Option<u32>>
An arbitrary tag to further specify the destination for this escrow, such as a hosted recipient at the destination address.
Sourcefn owner_node(&self) -> Result<u64>
fn owner_node(&self) -> Result<u64>
A hint indicating which page of the sender’s owner directory links to this entry, in case the directory consists of multiple pages.
Sourcefn previous_txn_id(&self) -> Result<Hash256>
fn previous_txn_id(&self) -> Result<Hash256>
The identifying hash of the transaction that most recently modified this entry.
Sourcefn previous_txn_lgr_seq(&self) -> Result<u32>
fn previous_txn_lgr_seq(&self) -> Result<u32>
The index of the ledger that contains the transaction that most recently modified this entry.
Sourcefn destination_node(&self) -> Result<Option<u64>>
fn destination_node(&self) -> Result<Option<u64>>
A hint indicating which page of the destination’s owner directory links to this object, in case the directory consists of multiple pages. Omitted on escrows created before enabling the fix1523 amendment.
Sourcefn transfer_rate(&self) -> Result<Option<u32>>
fn transfer_rate(&self) -> Result<Option<u32>>
The transfer rate or fee to charge when users finish an escrow, locked at the creation of an escrow contract and used during settlement. Applicable to Trust Line Tokens and MPTs only.
Sourcefn issuer_node(&self) -> Result<Option<u64>>
fn issuer_node(&self) -> Result<Option<u64>>
The ledger index of the issuer’s directory node associated with the Escrow. Used when the
issuer is neither the source nor destination account.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".